@@ -1,6 +1,6 @@
 
 /*
- * $Header: /cvs/gnome/gperfmeter/src/perfmeter.c,v 1.58 2005/03/11 22:07:43 richb Exp $
+ * $Header: /cvs/gnome/gperfmeter/src/perfmeter.c,v 1.59 2005/05/17 17:31:01 richb Exp $
  *
  * Copyright (c) 1990-2004 Sun Microsystems, Inc. All Rights Reserved.
  *
@@ -106,7 +106,7 @@ void PutResource(char *, char *, char *, ResType, gpointer);
 
 /* Menubar menu and popup menu entries. */
 
-static GtkActionEntry entries[] = {
+static const GtkActionEntry entries[] = {
     { "FileMenu",       NULL, N_("_File") },
     { "EditMenu",       NULL, N_("_Edit") },
     { "ViewMenu",       NULL, N_("_View") },
@@ -126,7 +126,7 @@ static GtkActionEntry entries[] = {
 };
 static guint n_entries = G_N_ELEMENTS(entries);
 
-static GtkToggleActionEntry toggle_entries[] = {
+static const GtkToggleActionEntry toggle_entries[] = {
     { "CPU",  NULL, N_("_CPU"),               "<control>1",
       N_("Show CPU metrics"),           G_CALLBACK(menu_handler), FALSE },
     { "Load",  NULL, N_("_Load"),             "<control>2",
@@ -153,7 +153,7 @@ static GtkToggleActionEntry toggle_entries[] = {
 };
 static guint n_toggle_entries = G_N_ELEMENTS(toggle_entries);
 
-static GtkRadioActionEntry chart_radio_entries[] = {
+static const GtkRadioActionEntry chart_radio_entries[] = {
   { "BarChart",    NULL, N_("_Bar Chart"),   NULL,
     N_("Show bar chart"),    M_BAR },
   { "StripChart",  NULL, N_("_Strip Chart"), NULL,
