@@ -1,6 +1,6 @@
 
 /*
- * $Header: /cvs/gnome/gperfmeter/src/perfmeter.h,v 1.21 2004/11/15 17:12:49 richb Exp $
+ * $Header: /cvs/gnome/gperfmeter/src/perfmeter.h,v 1.28 2005/07/01 18:00:41 laca Exp $
  *
  * Copyright (c) 1990-2004 Sun Microsystems, Inc. All Rights Reserved.
  *
@@ -31,6 +31,7 @@
 #include <sys/param.h>
 #include <sys/time.h>
 #include <sys/stat.h>
+#include <string.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
 #include <netdb.h>
@@ -47,6 +48,7 @@
 #include <nl_types.h>
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
@@ -69,15 +71,11 @@
 #define GETTIMEOFDAY             (void) gettimeofday
 #define KILL                     (void) kill
 #define MEMCPY                   (void) memcpy
-#define MEMMOVE                  (void) memmove
 #define MEMSET                   (void) memset
-#define PRINTF                   (void) printf
 #define SETLOCALE                (void) setlocale
 #define SETPGID                  (void) setpgid
 #define SIGNAL                   (void) signal
 #define SLEEP                    (void) sleep
-#define SPRINTF                  (void) sprintf
-#define STRCAT                   (void) strcat
 #define STRCPY                   (void) strcpy
 #define TEXTDOMAIN               (void) textdomain
 
@@ -109,6 +107,8 @@
 #define PmDATA_INCREMENT   100
 #define PmMESSAGE_FILE     ""
 
+#define EQUAL(a, b)    (strlen(a)==strlen(b)) & !strcmp(a, b)
+
 /* Macros */
 
 #define PmMax(a, b)         (((a) > (b)) ? (a) : (b))
@@ -166,6 +166,9 @@ typedef struct _PmUIStruct {
     gint mbHeight;                         /* Menubar height (in pixels). */
     guint TimerId;
 
+    GtkUIManager *ui;
+    GtkActionGroup *actions;
+
     GtkWidget *MainWin;
     GtkWidget *MenuBar;
     GtkWidget *VBox;
@@ -173,22 +176,19 @@ typedef struct _PmUIStruct {
     GtkWidget *MeterHBox;   /* Box for meters (when displayed horizontally). */
     GtkWidget *MeterVBox;   /* Box for meters (when displayed vertically). */
     GtkWidget *GMeters[PmMAX_METERS]; /* gnome-perfmeter meter widgets. */
+    GtkWidget *HostName;    /* Label for remote hostname (or "localhost"). */
 
     GtkAccelGroup *accel;   /* You need this for alt-hotkeys on menus */
-    GtkItemFactory *fact;   /* Menubar item factory */
-    GtkItemFactory *pfact;  /* Popup menu item factory */
     int initializing;       /* To work around some idiocy in gtk callbacks */
     GtkWidget *Aboutdialog;
     GtkWidget *PopupMenu;
-    GtkWidget *ViewMeters[PmMAX_METERS];
-    GtkWidget *PopupMeters[PmMAX_METERS];
     PmUIMeterStruct *Meters;
     GdkColor FgPixel;
     GdkColor BgPixel;
     PmString XmStrNULL;
     GdkBitmap *IconBM;
-    GdkPixmap *DeadPM;
-    GdkPixmap *SickPM;
+    GdkPixbuf *DeadPM;
+    GdkPixbuf *SickPM;
     gboolean UseColor;               /* Later ... */
     GdkGC *CanvasGC;
     GdkFont *LabelFont;    
@@ -258,7 +258,7 @@ typedef struct _PmStruct {
     unsigned int SickHp;           /* Sick icon height */
     int OldSocket;                 /* Old socket connection id */
     int RpcVersion;                /* RPC version number */
-    char Hostname[MAXHOSTNAMELEN]; /* Name of host being metered */
+    gchar *Hostname;               /* Name of host being metered */
     char *LocalHost;               /* Local host name */
     char *LocalAddr;               /* Local host address */
     char *LocalMachine;            /* Name of local machine */
@@ -267,12 +267,13 @@ typedef struct _PmStruct {
     int ShortExp;
     int LongExp;
     FILE *SampleFP;                /* File descriptor for sample file */
-    char LogFilename[PATH_MAX];
+    gchar *LogFilename;
     gboolean Log;
     gboolean ShowLimit;            /* Show ceiling limit line */
     int LogLineCount;
     int LogPageLength;
     gboolean CollectWhenIconized;
+    gboolean ShowHostName;
     gboolean ShowMenubar;
     gboolean ShowStripChart;
     gboolean ShowLiveActionBar;
@@ -361,7 +362,7 @@ extern gboolean PmMonitor(void);
 extern void PmSetMeterColor(int);
 extern void PmSetColors(void);
 extern void PmSaveResources();
-extern void PmExpandPathname(char *, char *);
+extern gchar *expand_tilde(const char *);
 extern void PmResetProps(void);
 extern void PmRefresh(gboolean);
 extern void PmResetCurMax(int);
@@ -382,7 +383,7 @@ extern void PmPropsSetDisplayList(void);
 extern void PmAllocateColor(int, gboolean);
 extern void PmSaveCommand(void);
 
-extern void set_title(void);
+extern void set_hostname(void);
 extern void ToggleDirection(gint);
 extern void ToggleMenuBar(int);
 extern void ValidateStripBarMenu(void);
